import 'package:country_pickers/country.dart' as ctry;
import 'package:country_pickers/country_pickers.dart';
import 'package:flutter/material.dart';

class CountryDialog extends StatelessWidget {
  final Function(Country country) onPicked;
  const CountryDialog({Key key, this.onPicked}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return CountryPickerDialog(
      titlePadding: EdgeInsets.all(8.0),
      searchInputDecoration: InputDecoration(hintText: 'Search...'),
      isSearchable: true,
      title: Text('Select your country'),
      onValuePicked: (ctry.Country country) {
        var result = Country.named(
            iso3Code: country.iso3Code,
            isoCode: country.isoCode,
            name: country.name,
            phoneCode: country.phoneCode);
        if (onPicked != null) {
          onPicked(result);
        }
      },
      itemFilter: (c) => true,
      itemBuilder: (country) {
        return Row(
          children: <Widget>[
            Expanded(child: Text(country.name)),
            SizedBox(width: 8.0),
            Material(
              elevation: 2.0,
              child: CountryPickerUtils.getDefaultFlagImage(country),
            ),
          ],
        );
      },
    );
  }
}

class Country {
  final String name;
  final String isoCode;
  final String iso3Code;
  final String phoneCode;
  Country(this.isoCode, this.iso3Code, this.phoneCode, this.name);

  Country.named({this.isoCode, this.iso3Code, this.phoneCode, this.name});
}
